<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ClipGrab</name>
    <message>
        <location filename="clipgrab.cpp" line="36"/>
        <source>Automatic language recognition</source>
        <translation>Automatische Spracherkennung</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="512"/>
        <source>Downloading update … %1/%2 MBytes</source>
        <translation>Update wird heruntergeladen … %1/%2 MByte</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="521"/>
        <source>There was an error while downloading the update.: %1</source>
        <translation>Beim Herunterladen des Updates ist ein Fehler aufgetreten: %1</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="535"/>
        <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
        <translation>Fehler beim Überprüfen der Integrität des Updates. Prüfsumme: %1 Erwartet: %2</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="547"/>
        <source>Could not open update file.</source>
        <translation>Das Update konnte nicht geöffnet werden.</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="585"/>
        <source>Unable to write to %1</source>
        <translation>Konnte Datei nicht speichern: %1</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="607"/>
        <source>SSL error: %1 
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="614"/>
        <source>Error downloading youtube-dl: %1</source>
        <translation>Fehler beim Herunterladen von youtube-dl: %1</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
</context>
<context>
    <name>DownloadListModel</name>
    <message>
        <location filename="download_list_model.cpp" line="99"/>
        <source>Starting ...</source>
        <translation>Vorbereiten ...</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="106"/>
        <source>Converting ...</source>
        <translation>Konvertieren ...</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="108"/>
        <source>Finished</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="110"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="112"/>
        <source>Canceled</source>
        <translation>Abgebrochen</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="114"/>
        <source>Waiting</source>
        <translation>Warten</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="116"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Portal</source>
        <translation>Seite</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Quality</source>
        <translation>Qualität</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
</context>
<context>
    <name>HelperDownloader</name>
    <message>
        <location filename="helper_downloader.ui" line="14"/>
        <source>Dialog</source>
        <translation>youtube-dl herunterladen</translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="20"/>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="27"/>
        <source>Exit ClipGrab</source>
        <translation>ClipGrab beenden</translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="85"/>
        <source>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to download youtube-dl.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to automatically download youtube-dl.&lt;/p&gt;</oldsource>
        <translation>&lt;p&gt;ClipGrab verwendet youtube-dl, um Videos aus dem Netz zu laden. youtube-dl wird von einem unabhängigen Team von Open-Source-Entwicklern entwickelt und in die Public Domain veröffentlicht.&lt;br&gt;Erfahre mehr auf&lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Klicke auf &lt;em&gt;Weiter&lt;/em&gt;, um youtube-dl herunterzuladen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="99"/>
        <source>Downloading youtube-dl</source>
        <translation>youtube-dl herunterladen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="273"/>
        <source>Select Target</source>
        <translation>Zieldatei auswählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="74"/>
        <source>Please wait while ClipGrab is loading information about the video ...</source>
        <translation>Einen Moment Geduld, während ClipGrab Informationen über das Video lädt ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Um ein Video herunterzuladen, musst Du den Video-Link in das Eingabefeld einfügen.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
        <translation>Auf dieser Seite wurde leider kein Video gefunden.&lt;br /&gt; Vielleicht hast Du einen falschen Link eingegeben oder es liegt ein Problem mit Deiner Internetverbindung vor.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab: Video discovered in your clipboard</source>
        <translation>ClipGrab: Video in der Zwischenablage</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
        <translation>ClipGrab hat den Link zu einem kompatiblen Video in der Zwischenablage gefunden. Hier klicken, um es jetzt herunterzuladen.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>ClipGrab - Exit confirmation</source>
        <translation>ClipGrab - Sicherheitsabfrage</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
        <translation>Es wird momentan noch mindestens ein Video heruntergeladen.&lt;br /&gt;Wird ClipGrab nun beendet, werden alle Downloads abgebrochen und können später nicht wiederhergestellt werden.&lt;br/&gt;Soll ClipGrab wirklich beendet werden?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Downloading and converting “%title” is now finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>All downloads finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>ClipGrab has finished downloading and converting all selected videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="683"/>
        <source>No results found.</source>
        <translation>Keine Ergebnisse gefunden.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="740"/>
        <source>&amp;Open downloaded file</source>
        <translation>&amp;Heruntergeladene Datei öffnen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="741"/>
        <source>Open &amp;target folder</source>
        <translation>&amp;Zielordner öffnen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="743"/>
        <source>&amp;Pause download</source>
        <translation>Download &amp;pausieren</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="744"/>
        <source>&amp;Restart download</source>
        <translation>Download &amp;neustarten</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="745"/>
        <source>&amp;Cancel download</source>
        <translation>Download &amp;abbrechen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="747"/>
        <source>Copy &amp;video link</source>
        <translation>Videolink &amp;kopieren</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="748"/>
        <source>Open video link in &amp;browser</source>
        <translation>Videolink im &amp;Browser öffnen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="751"/>
        <source>Resume download</source>
        <translation>Download &amp;fortsetzen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="764"/>
        <source>Show in &amp;Finder</source>
        <translation>Im &amp;Finder anzeigen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="376"/>
        <source>ClipGrab - Select target path</source>
        <translation>ClipGrab - Zielverzeichnis auswählen</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation>ClipGrab - Herunterladen und Konvertieren von Onlinevideos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="343"/>
        <source>Current Downloads:</source>
        <translation>Momentane Downloads:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="453"/>
        <source>Here you can configure where the downloaded videos are to be saved.</source>
        <translation>Hier kann festgelegt werden, wo ClipGrab heruntergeladene Videos speichern soll.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <source>Browse ...</source>
        <translation>Durchsuchen ...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="522"/>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="549"/>
        <source>Always ask</source>
        <translation>Immer nachfragen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Never download</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="373"/>
        <source>Pause selected download</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
        <translation>Hier können allgemeine Einstellungen vorgenommen werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="433"/>
        <source>Target Path</source>
        <translation>Zielordner</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="439"/>
        <source>Always save at the last used path.</source>
        <translation>Immer den zuletzt gewählten Ordner verwenden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Never ask for file name</source>
        <translation>Nicht nach dem Dateinamen fragen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="488"/>
        <source>Metadata</source>
        <translation>Metadaten</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
        <translation>Wenn für MP3-Dateien Metadaten (ID3-Tags) verwendet werden sollen, kann dies hier eingestellt werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="501"/>
        <source>Use metadata</source>
        <translation>Metadaten benutzen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="528"/>
        <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
        <translation>Welche Aktion soll ClipGrab durchführen, wenn ein Link zu einem Video in der Zwischenablage gefunden wurde?</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="535"/>
        <source>Always download</source>
        <translation>Immer herunterladen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="570"/>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <source>After each download</source>
        <translation>Nach jedem Download</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="583"/>
        <source>After all downloads have been completed</source>
        <translation>Nachdem alle Downloads abgeschlossen sind</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
        <translation>Hier kann eingestellt werden, wann ClipGrab Benachrichtigungen anzeigen soll.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="610"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="618"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <source>Use a proxy server</source>
        <translation>Einen Proxy-Server verwenden</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Proxy settings</source>
        <translation>Proxy-Einstellungen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="643"/>
        <source>Hostname/IP:</source>
        <translation>Hostname/IP:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="650"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="677"/>
        <source>Proxy type:</source>
        <oldsource>Proxy type</oldsource>
        <translation>Proxy-Typ:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="685"/>
        <source>HTTP Proxy</source>
        <translation>HTTP-Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="690"/>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="717"/>
        <source>Proxy authentication</source>
        <translation>Proxy-Authentifizierung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="723"/>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="740"/>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="753"/>
        <source>Proxy requires authentication</source>
        <translation>Proxy mit Authentifizierung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="761"/>
        <source>Other</source>
        <translation>Weiteres</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>Remove finished downloads from list</source>
        <translation>Abgeschlossene Downloads aus der Liste entfernen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1182"/>
        <source>&lt;h2&gt;Thanks&lt;/h2&gt;
ClipGrab relies on the work of the Qt project, the ffmpeg team, and the youtube-dl team.&lt;br&gt;
Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt;, and &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;Danksagungen&lt;/h2&gt;
ClipGrab wäre ohne die Arbeit des Qt.Project, des ffmpeg-Teams und des youtube-dl-Teams nicht möglich.&lt;br&gt;
Besuche &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt; und&lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; für weitere Informationen.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="767"/>
        <source>Minimize ClipGrab to the system tray</source>
        <translation>ClipGrab beim Minimieren in den Systray verkleinern</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="774"/>
        <source>Use WebM if possible</source>
        <translation>Wenn möglich WebM-Format verwenden</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="781"/>
        <source>Ignore SSL errors</source>
        <translation>SSL-Fehler ignorieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="808"/>
        <source>Remember logins</source>
        <translation>Logins speichern</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="815"/>
        <source>Remember video quality</source>
        <translation>Videoqualität speichern</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="827"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="851"/>
        <source>Here you can change the language of ClipGrab.</source>
        <translation>Hier kann die Sprache der Benutzeroberfläche von ClipGrab eingestellt werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="858"/>
        <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
        <translation>Bitte wähle eine Sprache aus der Liste aus. Damit die Änderungen aktiviert werden, muss ClipGrab neu gestartet werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="895"/>
        <source>Conversion</source>
        <translation>Konvertierung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="918"/>
        <source>Experts can create custom presets for the video conversion here.</source>
        <translation>Experten können hier eigene Zielformate erstellen.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="925"/>
        <source>Format preset</source>
        <translation>Zielformatbezeichnung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Add new preset</source>
        <translation>Neues Format erstellen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="942"/>
        <source>Remove selected preset</source>
        <translation>Ausgewähltes Löschen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="965"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="977"/>
        <location filename="mainwindow.ui" line="1029"/>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1003"/>
        <location filename="mainwindow.ui" line="1091"/>
        <source>Bitrate (kb/s)</source>
        <translation>Bitrate (KB/s)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1010"/>
        <source>Disable Audio</source>
        <translation>Audio deaktivieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1042"/>
        <source>Frames/second</source>
        <translation>Bilder/Sekunde</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1101"/>
        <source>Disable video</source>
        <translation>Video deaktivieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1116"/>
        <source>About</source>
        <translation>Über ClipGrab</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1165"/>
        <source>&lt;h2&gt;Translation&lt;/h2&gt;
ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;Übersetzung&lt;/h2&gt;
ClipGrab ist schon in vielen Sprachen verfügbar. Wenn ClipGrab noch nicht in deiner Sprache verfügbar ist, besuche &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; um zu erfahren, wie du mithelfen kannst.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="199"/>
        <source>Grab this clip!</source>
        <translation>Dieses Video herunterladen!</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="234"/>
        <source>Quality:</source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1122"/>
        <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
&lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;ClipGrab unterstützen!&lt;/h2&gt;
&lt;p&gt;Nur mit Deiner Hilfe kann ClipGrab weiterhin kostenlos angeboten werden.&lt;br&gt;Wenn Du also Gefallen an ClipGrab gefunden hast, kannst Du die weitere Entwicklung mit einem freiwilligen Beitrag unterstützen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Enter keywords in the box below in order to search videos on YouTube</source>
        <translation>Um nach Videos bei YouTube zu suchen, kannst Du Suchbegriffe in das Eingabefeld eingeben.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>Um ein Video herunterzuladen, musst Du den Video-Link in das Eingabefeld einfügen.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="353"/>
        <source>Open the target folder of the selected download</source>
        <translation>Zielordner des ausgewählten Downloads öffnen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="363"/>
        <source>Cancel selected download</source>
        <translation>Ausgewählten Download abbrechen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="153"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="385"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="metadata-dialog.ui" line="14"/>
        <source>ClipGrab - enter metadata</source>
        <translation>ClipGrab - Metadaten eingeben</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="25"/>
        <source>Please enter the metadata for your download. If you don&apos;t want to add metadata, just leave the fields empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="45"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="52"/>
        <source>Artist:</source>
        <translation>Künstler:</translation>
    </message>
</context>
<context>
    <name>UpdateMessage</name>
    <message>
        <location filename="update_message.ui" line="14"/>
        <source>Update for ClipGrab</source>
        <translation>Update für ClipGrab</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="116"/>
        <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
        <translation>ClipGrab %1 ist nun verfügbar (Sie benutzen %2). Möchten Sie das Update installieren?</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="130"/>
        <source>There is an update for your version of ClipGrab!</source>
        <translation>Es gibt ein neues Update für ClipGrab!</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="64"/>
        <source>Skip this update</source>
        <translation>Diese Version überspringen</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="91"/>
        <source>Download update</source>
        <translation>Jetzt herunterladen</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="240"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="74"/>
        <source>Remind me later</source>
        <translation>Später erinnern</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="41"/>
        <source>The update will begin in just a moment …</source>
        <translation>Das Update wird gleich gestartet …</translation>
    </message>
</context>
<context>
    <name>converter_copy</name>
    <message>
        <location filename="converter_copy.cpp" line="28"/>
        <source>Original</source>
        <translation>Originalformat</translation>
    </message>
</context>
<context>
    <name>converter_ffmpeg</name>
    <message>
        <location filename="converter_ffmpeg.cpp" line="216"/>
        <source>MPEG4</source>
        <translation>MPEG4</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="217"/>
        <source>WMV (Windows)</source>
        <translation>WMV (Windows)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="218"/>
        <source>OGG Theora</source>
        <translation>OGG Theora</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="219"/>
        <source>MP3 (audio only)</source>
        <translation>MP3 (nur Audio)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="220"/>
        <source>OGG Vorbis (audio only)</source>
        <translation>OGG Vorbis (nur Audio)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="221"/>
        <source>Original (audio only)</source>
        <translation>Original (nur Audio)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="356"/>
        <source>No installed version of avconv or ffmpeg coud be found. Converting files and downloading 1080p videos from YouTube is not supported.</source>
        <translation>Keine installierte Version von avconv oder ffmpeg konnte gefunden werden. Das Konvertieren von Dateien und das Herunterladen von 1080p-Videos von YouTube wird nicht unterstützt.</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="371"/>
        <source>The installed version of %1 is outdated.
Downloading 1080p videos from YouTube is not supported.</source>
        <translation>Die installierte Version von %1 ist veraltet.
Das Herunterladen von 1080p-Videos von YouTube wird nicht unterstützt.</translation>
    </message>
</context>
<context>
    <name>messageDialog</name>
    <message>
        <location filename="message_dialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished">youtube-dl herunterladen</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="48"/>
        <source>Close this message</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="71"/>
        <source>about:blank</source>
        <translation type="unfinished">about:blank</translation>
    </message>
</context>
<context>
    <name>video</name>
    <message>
        <location filename="video.cpp" line="261"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
</context>
</TS>
